@@ -21,8 +21,18 @@ from keystoneauth1 import exceptions as ksa_exceptions
 from keystoneauth1.identity import generic as generic_plugin
 from keystoneauth1.identity.v3 import k2k
 from keystoneauth1 import loading
+from keystoneauth1 import noauth
 from keystoneauth1 import token_endpoint
-from os_client_config import cloud_config
+
+try:
+    from openstack.config import cloud_config
+    from openstack.config import defaults
+    _occ_in_sdk = True
+except ImportError:
+    from os_client_config import cloud_config
+    from os_client_config import defaults
+    _occ_in_sdk = False
+from openstack import connection
 
 from osc_lib.api import auth
 from osc_lib import clientmanager
@@ -72,6 +82,29 @@ class TestClientCache(utils.TestCase):
 
 class TestClientManager(utils.TestClientManager):
 
+    def test_client_manager_none(self):
+        none_auth = {
+            'endpoint': fakes.AUTH_URL,
+        }
+        client_manager = self._make_clientmanager(
+            auth_args=none_auth,
+            auth_plugin_name='none',
+        )
+
+        self.assertEqual(
+            fakes.AUTH_URL,
+            client_manager._cli_options.config['auth']['endpoint'],
+        )
+        self.assertIsInstance(
+            client_manager.auth,
+            noauth.NoAuth,
+        )
+        # Check that the endpoint option works as the override
+        self.assertEqual(
+            fakes.AUTH_URL,
+            client_manager.get_endpoint_for_service_type('baremetal'),
+        )
+
     def test_client_manager_admin_token(self):
         token_auth = {
             'endpoint': fakes.AUTH_URL,
@@ -305,16 +338,18 @@ class TestClientManager(utils.TestClientManager):
     def test_client_manager_auth_setup_once(self, check_authn_options_func):
         loader = loading.get_plugin_loader('password')
         auth_plugin = loader.load_from_options(**AUTH_DICT)
+        cli_options = defaults.get_defaults()
+        cli_options.update({
+            'auth_type': 'password',
+            'auth': AUTH_DICT,
+            'interface': fakes.INTERFACE,
+            'region_name': fakes.REGION_NAME,
+        })
         client_manager = self._clientmanager_class()(
             cli_options=cloud_config.CloudConfig(
                 name='t1',
                 region='1',
-                config=dict(
-                    auth_type='password',
-                    auth=AUTH_DICT,
-                    interface=fakes.INTERFACE,
-                    region_name=fakes.REGION_NAME,
-                ),
+                config=cli_options,
                 auth_plugin=auth_plugin,
             ),
             api_version={
@@ -350,18 +385,20 @@ class TestClientManager(utils.TestClientManager):
     def test_client_manager_k2k_auth_setup(self):
         loader = loading.get_plugin_loader('password')
         auth_plugin = loader.load_from_options(**AUTH_DICT)
+        cli_options = defaults.get_defaults()
+        cli_options.update({
+            'auth_type': 'password',
+            'auth': AUTH_DICT,
+            'interface': fakes.INTERFACE,
+            'region_name': fakes.REGION_NAME,
+            'service_provider': fakes.SERVICE_PROVIDER_ID,
+            'remote_project_id': fakes.PROJECT_ID
+        })
         client_manager = self._clientmanager_class()(
             cli_options=cloud_config.CloudConfig(
                 name='t1',
                 region='1',
-                config=dict(
-                    auth_type='password',
-                    auth=AUTH_DICT,
-                    interface=fakes.INTERFACE,
-                    region_name=fakes.REGION_NAME,
-                    service_provider=fakes.SERVICE_PROVIDER_ID,
-                    remote_project_id=fakes.PROJECT_ID
-                ),
+                config=cli_options,
                 auth_plugin=auth_plugin,
             ),
             api_version={
@@ -377,3 +414,19 @@ class TestClientManager(utils.TestClientManager):
         self.assertEqual(client_manager.auth._sp_id, fakes.SERVICE_PROVIDER_ID)
         self.assertEqual(client_manager.auth.project_id, fakes.PROJECT_ID)
         self.assertTrue(client_manager._auth_setup_completed)
+
+
+class TestClientManagerSDK(utils.TestClientManager):
+
+    def test_client_manager_connection(self):
+        client_manager = self._make_clientmanager(
+            auth_required=True,
+        )
+
+        if _occ_in_sdk:
+            self.assertIsInstance(
+                client_manager.sdk_connection,
+                connection.Connection,
+            )
+        else:
+            self.assertIsNone(getattr(client_manager, 'sdk_connection', None))
